Glossary
========

.. glossary::

    Hardware certification

        A process of ensuring that a specific device works well with Ubuntu.
        For more details see our certification program:

        https://certification.ubuntu.com/certification/

    Hardware certification team

        A team inside Canonical working on :term:`Hardware Certification`.

    Checkbox

        Checkbox is a hardware testing tool developed by Canonical for
        certifying hardware with Ubuntu. Checkbox is free software and is
        available at http://launchpad.net/checkbox. 

    Checkbox-ng

        Name of the package in Ubuntu Archive that contains Checkbox.

    Plainbox

        Plainbox is a functional core of the Checkbox.
        These days it's almost synonymous with Checkbox.

    Test plan

        Test plans are text files used by Checkbox to select jobs for
        execution. They can include simple regular expressions to match and
        pick many similar jobs at once.

    Job

        Jobs are smallest units of testing that can be performed by Checkbox.
        All jobs have a unique name. There are many types of jobs, some are
        fully automated others are fully manual. Some jobs are only an
        implementation detail and a part of the internal architecture of
        Checkbox.

    Provider

        A container for jobs, test plans, private executables and data.
        Providers are the foundation of Checkbox as they *provide* all of the
        content. Providers can be created and managed by any entity, separately
        from the Checkbox project.

    Namespace

        A private space for naming job definitions. Each job definition has a
        partial identifier and a full identifier (typically just called job
        id).  The partial identifier is encoded in job definition file. The
        full identifier is composed of the namespace of a job provider and the
        partial identifier, joined with the double-colon string ``::``.

    Resources

        Resources are collections of key-value data sets that are generated by
        special resource jobs. They are extensively used to indicate hardware
        or software dependencies. For example a bluetooth test may indicate it
        requires bluetooth hardware and appropriate software packages
        installed.

    Bootstrapping

        Phase of a Checkbox session where resource jobs are executed to gather
        information about the hardware.

    Requirement program

        Requirement programs are small (one to few lines) programs that use a
        subset of python to execute some code against resources. They are what
        actually describes the relationship of a Job to some Resources. For
        example a resource program ``package.name == "bluez"`` indicates that
        at least one resource generated by the ``package`` job has a key
        ``name`` equal to the string ``bluez``.

    Attachment

        Attachments are a special type of a Job that can create an attachment
        record in the submission reports. They are commonly used to include
        basic system information files and output of certain commands which can
        aid in system certification.

    Certification Website

        The website https://certification.canonical.com/

    Secure ID

        An identifier, similar to Canonical ID, used for hardware
        certification. This identifier is used when interacting with the
        Certification Website, it does not reveal anything about the actual
        hardware (like the manufacturer name or device name).

    PyPI

        The Python Package Index where any developer can share their python
        programs and libraries. PyPI is available at:
        https://pypi.org/.
